"""
DroidRun CLI Module.

This module provides command-line interfaces for interacting with Android devices.
"""

from droidrun.cli.main import cli

__all__ = ["cli"] 